==> beast-privilege-api-2.6.4-sources.jar: com/thebeastshop/privilege/vo/StoremanTaskmanagerDetailVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerDetailVO implements Serializable {
    private Integer id;
    private Integer taskId;
    private Integer memberId;
    private String label;
    private Integer startUserLevel;
    private Integer endUserLevel;
    private BigDecimal upgradeAmount;
    private String channelCode;
    private Integer userId;
    private String userMan;
    private Integer processClass;
    private String moreNote;




    private List<String> extLabelList;
    private String extMemberCode;
    private String extNickName;
    private String  extBirthDay;
    private String extMobile;
    private String extChannelName;
    private Integer extUserLevel;
    private String extUserlevelDesc;
    private Integer extIsFinsh;
    private String extLastOrderStr;


    private List<ValueLabelIntVO> channelStoreUserList;
    private List<OrderDetailVO> orderDetailList;




    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getTaskId() {
        return taskId;
    }

    public void setTaskId(Integer taskId) {
        this.taskId = taskId;
    }

    public Integer getMemberId() {
        return memberId;
    }

    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getStartUserLevel() {
        return startUserLevel;
    }

    public void setStartUserLevel(Integer startUserLevel) {
        this.startUserLevel = startUserLevel;
    }

    public Integer getEndUserLevel() {
        return endUserLevel;
    }

    public void setEndUserLevel(Integer endUserLevel) {
        this.endUserLevel = endUserLevel;
    }

    public BigDecimal getUpgradeAmount() {
        return upgradeAmount;
    }

    public void setUpgradeAmount(BigDecimal upgradeAmount) {
        this.upgradeAmount = upgradeAmount;
    }
    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getUserId() {
        return userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public String getUserMan() {
        return userMan;
    }

    public void setUserMan(String userMan) {
        this.userMan = userMan;
    }

    public Integer getProcessClass() {
        return processClass;
    }

    public void setProcessClass(Integer processClass) {
        this.processClass = processClass;
    }

    public String getMoreNote() {
        return moreNote;
    }

    public void setMoreNote(String moreNote) {
        this.moreNote = moreNote;
    }



    public List<String> getExtLabelList() {
        return extLabelList;
    }

    public void setExtLabelList(List<String> extLabelList) {
        this.extLabelList = extLabelList;
    }

    public String getExtMemberCode() {
        return extMemberCode;
    }

    public void setExtMemberCode(String extMemberCode) {
        this.extMemberCode = extMemberCode;
    }

    public String getExtNickName() {
        return extNickName;
    }

    public void setExtNickName(String extNickName) {
        this.extNickName = extNickName;
    }

    public String getExtBirthDay() {
        return extBirthDay;
    }

    public void setExtBirthDay(String extBirthDay) {
        this.extBirthDay = extBirthDay;
    }

    public String getExtMobile() {
        return extMobile;
    }

    public void setExtMobile(String extMobile) {
        this.extMobile = extMobile;
    }

    public String getExtChannelName() {
        return extChannelName;
    }

    public void setExtChannelName(String extChannelName) {
        this.extChannelName = extChannelName;
    }


    public Integer getExtUserLevel() {
        return extUserLevel;
    }

    public void setExtUserLevel(Integer extUserLevel) {
        this.extUserLevel = extUserLevel;
    }
    public String getExtUserlevelDesc() {
        return extUserlevelDesc;
    }

    public void setExtUserlevelDesc(String extUserlevelDesc) {
        this.extUserlevelDesc = extUserlevelDesc;
    }

    public Integer getExtIsFinsh() {
        return extIsFinsh;
    }

    public void setExtIsFinsh(Integer extIsFinsh) {
        this.extIsFinsh = extIsFinsh;
    }

    public String getExtLastOrderStr() {
        return extLastOrderStr;
    }

    public void setExtLastOrderStr(String extLastOrderStr) {
        this.extLastOrderStr = extLastOrderStr;
    }

    public List<ValueLabelIntVO> getChannelStoreUserList() {
        return channelStoreUserList;
    }

    public void setChannelStoreUserList(List<ValueLabelIntVO> channelStoreUserList) {
        this.channelStoreUserList = channelStoreUserList;
    }

    public List<OrderDetailVO> getOrderDetailList() {
        return orderDetailList;
    }

    public void setOrderDetailList(List<OrderDetailVO> orderDetailList) {
        this.orderDetailList = orderDetailList;
    }


}

==> beast-privilege-api-2.6.8-sources.jar: com/thebeastshop/privilege/vo/StoremanTaskmanagerDetailVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerDetailVO implements Serializable {
    private Integer id;
    private Integer taskId;
    private Integer memberId;
    private String label;
    private Integer startUserLevel;
    private Integer endUserLevel;
    private BigDecimal upgradeAmount;
    private String channelCode;
    private Integer userId;
    private String userMan;
    private Integer processClass;
    private String moreNote;

    private Date expireDate;

    private BigDecimal expireIntegral;





    private List<String> extLabelList;
    private String extMemberCode;
    private String extNickName;
    private String  extBirthDay;
    private String extMobile;
    private String extChannelName;
    private Integer extUserLevel;
    private String extUserlevelDesc;
    private Integer extIsFinsh;
    private String extLastOrderStr;


    private List<ValueLabelIntVO> channelStoreUserList;
    private List<OrderDetailVO> orderDetailList;




    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getTaskId() {
        return taskId;
    }

    public void setTaskId(Integer taskId) {
        this.taskId = taskId;
    }

    public Integer getMemberId() {
        return memberId;
    }

    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getStartUserLevel() {
        return startUserLevel;
    }

    public void setStartUserLevel(Integer startUserLevel) {
        this.startUserLevel = startUserLevel;
    }

    public Integer getEndUserLevel() {
        return endUserLevel;
    }

    public void setEndUserLevel(Integer endUserLevel) {
        this.endUserLevel = endUserLevel;
    }

    public BigDecimal getUpgradeAmount() {
        return upgradeAmount;
    }

    public void setUpgradeAmount(BigDecimal upgradeAmount) {
        this.upgradeAmount = upgradeAmount;
    }
    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getUserId() {
        return userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public String getUserMan() {
        return userMan;
    }

    public void setUserMan(String userMan) {
        this.userMan = userMan;
    }

    public Integer getProcessClass() {
        return processClass;
    }

    public void setProcessClass(Integer processClass) {
        this.processClass = processClass;
    }

    public String getMoreNote() {
        return moreNote;
    }

    public void setMoreNote(String moreNote) {
        this.moreNote = moreNote;
    }



    public Date getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(Date expireDate) {
        this.expireDate = expireDate;
    }

    public BigDecimal getExpireIntegral() {
        return expireIntegral;
    }

    public void setExpireIntegral(BigDecimal expireIntegral) {
        this.expireIntegral = expireIntegral;
    }


    public List<String> getExtLabelList() {
        return extLabelList;
    }

    public void setExtLabelList(List<String> extLabelList) {
        this.extLabelList = extLabelList;
    }

    public String getExtMemberCode() {
        return extMemberCode;
    }

    public void setExtMemberCode(String extMemberCode) {
        this.extMemberCode = extMemberCode;
    }

    public String getExtNickName() {
        return extNickName;
    }

    public void setExtNickName(String extNickName) {
        this.extNickName = extNickName;
    }

    public String getExtBirthDay() {
        return extBirthDay;
    }

    public void setExtBirthDay(String extBirthDay) {
        this.extBirthDay = extBirthDay;
    }

    public String getExtMobile() {
        return extMobile;
    }

    public void setExtMobile(String extMobile) {
        this.extMobile = extMobile;
    }

    public String getExtChannelName() {
        return extChannelName;
    }

    public void setExtChannelName(String extChannelName) {
        this.extChannelName = extChannelName;
    }


    public Integer getExtUserLevel() {
        return extUserLevel;
    }

    public void setExtUserLevel(Integer extUserLevel) {
        this.extUserLevel = extUserLevel;
    }
    public String getExtUserlevelDesc() {
        return extUserlevelDesc;
    }

    public void setExtUserlevelDesc(String extUserlevelDesc) {
        this.extUserlevelDesc = extUserlevelDesc;
    }

    public Integer getExtIsFinsh() {
        return extIsFinsh;
    }

    public void setExtIsFinsh(Integer extIsFinsh) {
        this.extIsFinsh = extIsFinsh;
    }

    public String getExtLastOrderStr() {
        return extLastOrderStr;
    }

    public void setExtLastOrderStr(String extLastOrderStr) {
        this.extLastOrderStr = extLastOrderStr;
    }

    public List<ValueLabelIntVO> getChannelStoreUserList() {
        return channelStoreUserList;
    }

    public void setChannelStoreUserList(List<ValueLabelIntVO> channelStoreUserList) {
        this.channelStoreUserList = channelStoreUserList;
    }

    public List<OrderDetailVO> getOrderDetailList() {
        return orderDetailList;
    }

    public void setOrderDetailList(List<OrderDetailVO> orderDetailList) {
        this.orderDetailList = orderDetailList;
    }


}
